/**
 *    @file  libhttp.h
 *   @brief  HTTP parsing and building library
 *
 *  <+DETAILED+>
 *
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  19/11/2024
 *      Revision:  none
 * Last modified:  2024-11-19 21:29
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifndef __LIBHTTP_H__
#define __LIBHTTP_H__

typedef struct HTTP_s HTTP_t;

typedef enum HTTPVersion_e {
    HTTPVERSION_HTTP09,
    HTTPVERSION_HTTP10,
    HTTPVERSION_HTTP11,
    HTTPVERSION_HTTP11b,
    HTTPVERSION_HTTP2,
    HTTPVERSION_HTTP3,
    HTTPVERSION_INVALID
} HTTPVersion_t;

typedef enum HTTPMethod_e {
    HTTPMETHOD_GET,
    HTTPMETHOD_HEAD,
    HTTPMETHOD_POST,
    HTTPMETHOD_PUT,
    HTTPMETHOD_DELETE,
    HTTPMETHOD_CONNECT,
    HTTPMETHOD_OPTIONS,
    HTTPMETHOD_TRACE,
    HTTPMETHOD_PATCH,
    HTTPMETHOD_INVALID
} HTTPMethod_t;

HTTP_t* HTTP_new();
void HTTP_addheader(HTTP_t* http, const char* name, const char* value);
char* HTTP_getheaders(const HTTP_t* http);
void HTTP_del(HTTP_t* http);
char* HTTP_getrequest(const HTTPMethod_t method, const char* uri, const HTTPVersion_t version);
void HTTP_setbody(HTTP_t* http, const char* body);
char* HTTP_getbody(HTTP_t* http);

#endif /* __LIBHTTP_H__ */
